Project::OSiRiON - Git repositories
Project::OSiRiON
News . About . Screenshots . Downloads . Forum . Wiki . Tracker . Git
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorStijn Buys <ingar@osirion.org>2008-08-15 13:05:58 +0000
committerStijn Buys <ingar@osirion.org>2008-08-15 13:05:58 +0000
commit62de0496836e729ff955274cf153914709775bfb (patch)
tree54a868d8e4620b4dad49881af7a2614128697cbf /src/model/map.h
parent68fc01c7ce3f089e10a53e6dac92e2f63a9a8efd (diff)
func_group support
Diffstat (limited to 'src/model/map.h')
-rw-r--r--src/model/map.h21
1 files changed, 18 insertions, 3 deletions
diff --git a/src/model/map.h b/src/model/map.h
index afe925b..5137e6c 100644
--- a/src/model/map.h
+++ b/src/model/map.h
@@ -63,7 +63,16 @@ private:
/// true if the last read line contained a new classname
bool got_classname() const;
+
+ /// true if the last read line contained a class closing bracket
+ inline bool got_classend() const
+ {
+ return last_read_was_classend;
+ }
+ /// true if the last read line contained the closing bracket for the requested class
+ bool got_classend(const char*) const;
+
/// true if the last read line contained a new classname
bool got_classname(const char*) const;
@@ -117,9 +126,12 @@ private:
/// generate triangles for one plane in the plane list
void make_brushface(Plane *face);
- /// load parsed primitives into Model Fragments
- void load_fragments(Model *model);
-
+ /// load parsed primitives into model worldspawn
+ void load_worldspawn(Model *model);
+
+ /// load parsed primitives into a FragmentGroup
+ void load_fragmentgroup(Model *model, FragmentGroup &group);
+
/// clear the current list of per-material geometry
void clear_materials();
@@ -132,6 +144,7 @@ private:
bool last_read_was_key;
bool last_read_was_classname;
+ bool last_read_was_classend;
unsigned int map_brushes;
unsigned int map_faces;
@@ -144,6 +157,8 @@ private:
math::Vector3f class_maxbbox;
math::Vector3f class_minbbox;
+
+ math::Vector3f map_center;
Materials map_materials;
};